@@ -453,6 +453,20 @@ class WorkflowTools(object):
         return output
 
 
+    @cherrypy.expose
+    @cherrypy.tools.json_out()
+    def actionssummary(self):
+        """
+        Get the workflow parameters
+        :param str workflow: The workflow that we need parameters for
+        :returns: Parameters for this workflow
+        :rtype: JSON
+        """
+
+        ret = manageactions.get_actions_summary()
+        return ret
+
+
     @cherrypy.expose
     @cherrypy.tools.json_out()
     def wkfparams(self, workflow):
